@@ -2,9 +2,8 @@ import hashlib
 import json
 import uuid
 from abc import ABC, abstractmethod
-
 from datetime import datetime
-from typing import Iterable, Optional
+from typing import Iterable, Optional, Any
 
 ENCODING = "UTF-8"
 
@@ -15,12 +14,13 @@ class NoSuchGameError(Exception):
 
 class Game:
 
-    def __init__(self, creator: str, players: Iterable[str], gid: str = None, creation_date: datetime = None):
+    def __init__(self, creator: str, players: Iterable[str], gid: str = None, custom: Any = None,
+                 creation_date: datetime = None):
         self.creator = creator
         self.players = tuple(players)
         self.gid = gid if gid else str(uuid.uuid4())
         self.creation_date = creation_date if creation_date else datetime.now().astimezone()
-        self.custom = None
+        self.custom = custom
 
     def tag(self):
         md5 = hashlib.md5()
@@ -36,7 +36,7 @@ class Game:
 class GameRepository(ABC):
 
     @abstractmethod
-    def create_game(self, creator: str, players: Iterable[str]) -> Game:
+    def create_game(self, creator: str, players: Iterable[str], custom: Any = None) -> Game:
         pass
 
     @abstractmethod
